# flower

开始于砰然心动 

# 安装
pip install fairies

# 主要功能
* txt,json,excel处理函数
- pdf抽取接口
* nlp常用工具

# 常用API

**label2id**
用于序列标注时标签和id相互转换  
**find_lcs**
查找公共子串  
**random_build_data**
按照比例切分数据集  
**removeLineFeed**
清洗数据中的去除换行 tab键  
**text_len_analysis**
分析数据中的文本长度  
**split_to_paragraph**
将文本切成句子  

